.. _utils:

Utilities
=================================

TOAST contains a variety of utilities for controlling the runtime environment, logging, timing, streamed random number generation, quaternion operations, FFTs, and special function evaluation.  In some cases these utilities provide a common interface to compile-time selected vendor math libraries.

.. include:: utils_env.inc

.. include:: utils_timing.inc

.. include:: utils_rng.inc

.. include:: utils_vmath.inc
